Chiplotle, the HP-GL Python library.

#### What is Chiplotle?

#### About the authors

#### Examples for the impatient

#### Tutorial

#### Chiplotle fundamentals

#### FAQ

#### Chiplotle-HPGL Reference

#### HPGL web resources

# Examples for the impatient

## Example 1

## Example 2

another example

## Example 3

Abstract Masterpiece Abstract Masterpiece demonstrates user input. It asks the user how many pens should be used, and then generates an abstract drawing that uses each pen.